# Generated by Django 3.0.13 on 2022-06-25 07:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('categories', '0008_mptt'),
    ]

    operations = [
        migrations.AddField(
            model_name='category',
            name='order',
            field=models.PositiveIntegerField(default=0),
        ),
    ]




from django.apps import AppConfig, apps
from django.utils.translation import gettext_lazy as _


class CategoriesAppConfig(AppConfig):

    name = 'categories'
    verbose_name = _('Categories')

    def ready(self):
        if not apps.is_installed('mptt'):
            raise Exception("`mp-categories` app depends on `django-mptt`")



# Generated by Django 3.0.10 on 2020-11-22 09:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('categories', '0005_logo'),
    ]

    operations = [
        migrations.AddField(
            model_name='category',
            name='icon',
            field=models.CharField(blank=True, max_length=255, verbose_name='Icon'),
        ),
    ]



# Generated by Django 3.0.10 on 2020-11-22 08:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('categories', '0002_title'),
    ]

    operations = [
        migrations.AddField(
            model_name='category',
            name='description',
            field=models.TextField(blank=True, max_length=4096, verbose_name='Description'),
        ),
    ]



# Generated by Django 3.0.13 on 2021-03-23 09:07

from django.db import migrations, models
import django.db.models.deletion
import mptt.fields


class Migration(migrations.Migration):

    dependencies = [
        ('categories', '0006_icon'),
    ]

    operations = [
        migrations.AddField(
            model_name='category',
            name='level',
            field=models.PositiveIntegerField(default=0, editable=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='category',
            name='lft',
            field=models.PositiveIntegerField(default=1, editable=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='category',
            name='parent',
            field=mptt.fields.TreeForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='children', to='categories.Category', verbose_name='Parent category'),
        ),
        migrations.AddField(
            model_name='category',
            name='rght',
            field=models.PositiveIntegerField(default=2, editable=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='category',
            name='tree_id',
            field=models.PositiveIntegerField(db_index=True, default=0, editable=False),
            preserve_default=False,
        ),
    ]



# Generated by Django 3.0.10 on 2020-11-22 09:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('categories', '0004_code'),
    ]

    operations = [
        migrations.AddField(
            model_name='category',
            name='logo',
            field=models.ImageField(blank=True, max_length=255, null=True, upload_to='categories', verbose_name='Logo'),
        ),
    ]




from django.contrib import admin
from django.utils.safestring import mark_safe
from django.utils.translation import gettext_lazy as _

from mptt.admin import MPTTModelAdmin
from cap.decorators import template_list_item

from categories.models import Category


class CategoryListFilter(admin.SimpleListFilter):
    title = _('Category')
    parameter_name = 'category'

    def lookups(self, request, model_admin):
        for category in Category.objects.root_nodes():
            yield category.pk, "*" + category.name
            for child in category.get_children():
                yield child.pk, mark_safe("—") + child.name

    def queryset(self, request, queryset):
        if not self.value():
            return queryset
        return queryset.filter(category_id=self.value())


@admin.register(Category)
class CategoryAdmin(MPTTModelAdmin):

    list_display = (
        'id', 'name', 'order', 'code', 'icon', 'product_count', 'get_preview'
    )

    list_editable = ('name', 'order')

    fields = (
        ('parent', 'code', ),
        'name',
        'title',
        ('logo', 'icon', ),
        'description',
    )

    search_fields = ('name', 'code')

    @template_list_item('admin/list_item_preview.html', _('Preview'))
    def get_preview(self, item):
        return {'file': item.logo}

    @admin.display(description=_('Product count'))
    def product_count(self, item):
        return item.products.count()




from os.path import join
from sxl import Workbook

from django.conf import settings
from django.core.management.base import BaseCommand

from categories.models import Category


class Command(BaseCommand):

    def add_arguments(self, parser):
        parser.add_argument('filename', type=str)

    def handle(self, *args, **options):

        wb = Workbook(join(settings.BASE_DIR, 'tmp', options['filename']))

        ws = wb.sheets['Export Groups Sheet']

        Category.objects.all().delete()

        categories = {}

        for row in ws.rows[2:]:
            code = str(int(row[0]))
            name_uk = row[2]
            name_ru = row[1]

            categories[code] = Category.objects.create(
                name=name_uk,
                name_uk=name_uk,
                name_ru=name_ru,
                title=name_uk,
                title_uk=name_uk,
                title_ru=name_ru,
                code=code
            )

        for row in ws.rows[2:]:
            code = str(int(row[0]))
            parent_code = row[4]

            if parent_code is None:
                continue

            parent_code = str(int(parent_code))

            category = categories[code]

            category.parent_id = categories[parent_code].pk
            category.save(update_fields=['parent_id'])

        Category.objects.rebuild()

        self.stdout.write(self.style.SUCCESS('Success'))




from django.db import models
from django.urls import reverse_lazy
from django.utils.text import slugify
from django.utils.translation import gettext_lazy as _

from django_prose_editor.fields import ProseEditorField
from mptt.forms import TreeNodeChoiceField
from mptt.models import MPTTModel, TreeForeignKey


class Category(MPTTModel):

    parent = TreeForeignKey(
        'self',
        on_delete=models.CASCADE,
        null=True,
        blank=True,
        related_name='children',
        verbose_name=_('Parent category'))

    name = models.CharField(
        _('Category name'),
        max_length=255)

    title = models.CharField(
        _('Category title'),
        max_length=255,
        blank=True)

    logo = models.ImageField(
        _('Logo'),
        upload_to='categories',
        blank=True,
        null=True,
        max_length=255)

    code = models.CharField(
        _('Code'),
        max_length=255,
        blank=True)

    icon = models.CharField(
        _('Icon'),
        max_length=255,
        blank=True)

    description = ProseEditorField(
        _('Description'),
        blank=True,
        extensions={
            'Bold': True,
            'Italic': True,
            'BulletList': True,
            'OrderedList': True,
            'ListItem': True,
            'Link': True,
            'Heading': {'levels': [1, 2, 3]},
        },
        sanitize=True,
    )

    order = models.PositiveIntegerField(default=0)

    def __str__(self):
        return self.name

    def get_absolute_url(self):
        return reverse_lazy('products:list', args=[self.slug, self.id])

    @property
    def slug(self):
        return slugify(self.name or 'category', allow_unicode=False).replace('-', '_')

    @property
    def full_name(self):
        return ' > '.join([
            c.name for c in self.get_ancestors(include_self=True)
        ])

    class MPTTMeta:
        order_insertion_by = ['order', 'name']

    class Meta:
        ordering = ['order']
        verbose_name = _('Category')
        verbose_name_plural = _('Categories')


class CategoryField(models.ForeignKey):

    def __init__(
            self,
            to='categories.Category',
            verbose_name=_('Category'),
            on_delete=models.CASCADE,
            db_index=True,
            *args, **kwargs):

        super(CategoryField, self).__init__(
            to,
            verbose_name=verbose_name,
            on_delete=on_delete,
            db_index=db_index,
            *args, **kwargs)

    def formfield(self, **kwargs):
        kwargs['form_class'] = TreeNodeChoiceField
        return super().formfield(**kwargs)



# Generated by Django 2.0.9 on 2020-03-24 20:28

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Category name')),
            ],
            options={
                'verbose_name': 'Category',
                'verbose_name_plural': 'Categories',
            },
        ),
    ]
